import React, { useEffect, useMemo, useState } from 'react'
import { Select, Radio, Space } from 'antd'
import { widgetData, getStyles } from '../../../../../constant'
import styles from './index.less'
import { isObject } from '../../../../../utils'
import Drag from '../../../../components/Drag'

const getNewSchema = (schema, { fieldName, widget }) => {
  let parent = schema?.properties
  if (isObject(parent)) {
    Object.keys(parent).forEach(keys => {
      let child = parent[keys]?.properties
      if (isObject(child)) {
        Object.keys(child).forEach(k => {
          if (k === fieldName) {
            let info = {
              tableNameParent: child[k].tableNameParent,
            }
            if (widget === 'TextInput') {
              child[k] = { title: '文本', type: 'string', widget: 'TextInput', placeholder: '', ...info, }
            }
            if (widget === 'TextArea') {
              child[k] = { title: '多行文本', type: 'string', widget: 'TextArea', placeholder: '', width: '100%', rows: 5, ...info, }
            }
            if (widget === 'ComboBox') {
              child[k] = {
                title: '下拉框',
                type: 'string',
                widget: 'ComboBox',
                sourceType: '手动输入',
                options: [{ value: '选项一' }],
                ...info,
              }
            }
            if (widget === 'RadioButton') {
              child[k] = {
                title: '单选框',
                name: '单选框',
                type: 'string',
                widget: 'RadioButton',
                sourceType: '手动输入',
                options: [{ value: '选项一' }],
                ...info,
              }
            }
            if (widget === 'CheckBox') {
              child[k] = {
                title: '复选框',
                name: '复选框',
                type: 'string',
                widget: 'CheckBox',
                sourceType: '手动输入',
                options: [{ value: '选项一' }],
                ...info,
              }
            }
          }
        })
      }
    })
  }
  return schema
}

const WidgetType = (props) => {

  const { value, onChange, addons } = props
  const [visible, setVisible] = useState(false)
  const [radioValue, setRadioValue] = useState(value)

  const transform = () => {
    if (value === radioValue) {
      return
    }
    let { $id } = addons?.formData
    let schema = window?.designerRef?.current.getValue()
    let newSchema = getNewSchema(schema, { fieldName: $id, widget: radioValue })
    window?.designerRef?.current.setValue(newSchema)
    setVisible(false)
  }

  const radioChange = (e) => {
    setRadioValue(e.target.value)
  }

  useEffect(() => {
    if (visible) {
      setRadioValue(value)
    }
  }, [visible])

  return (
    <div className={styles.widgetType}>
      <span
        className={styles.tag}
        style={getStyles(widgetData[value]?.type)}>
        {widgetData[value]?.name}
      </span>
      <span
        className={styles.text}
        onClick={() => setVisible(true)}
      >
        转化为其他控件
      </span>
      <Drag
        width={300}
        title='转化为其他控件'
        visible={visible}
        bodyStyle={{ height: '200px', overflow: 'auto' }}
        onOk={transform}
        onCancel={() => setVisible(false)}
        getContainer={false}
        destroyOnClose
      >
        <Radio.Group
          onChange={radioChange}
          value={radioValue}
        >
          <Space direction="vertical">
            <Radio value={'TextInput'}>文本</Radio>
            <Radio value={'TextArea'}>多行文本</Radio>
            <Radio value={'ComboBox'}>下拉框</Radio>
            <Radio value={'RadioButton'}>单选框</Radio>
            <Radio value={'CheckBox'}>复选框</Radio>
          </Space>
        </Radio.Group>
      </Drag>
    </div>
  )

}

export default WidgetType